pub enum Severity {
Hint,
Info,
Warning,
Error,
Off,
}Variants
Hint
A kind reminder for code with potential improvement.
Info
A suggestion that code can be improved or optimized.
Warning
A warning that code might produce bugs or does not follow best practice.
Error
An error that code produces bugs or has logic errors.
Off
Turns off the rule.