Label

Struct Label 

pub struct Label<'r, 't, D: Doc> {
    pub style: LabelStyle,
    pub message: Option<&'r str>,
    pub start_node: Node<'t, D>,
    pub end_node: Node<'t, D>,
}
A label is a way to mark a specific part of the code with a styled message. It is used to provide diagnostic information in LSP or CLI. ’r represents a lifetime for the message string from rule. ’t represents a lifetime for the node from a ast tree.

Fields

style: LabelStylemessage: Option<&'r str>start_node: Node<'t, D>end_node: Node<'t, D>

Implementations

Source

impl<'t, D: Doc> Label<'_, 't, D>

pub fn range(&self) -> Range<usize>